summaryrefslogtreecommitdiff
path: root/nuttx/drivers/usbhost/usbhost_storage.c
diff options
context:
space:
mode:
authorGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
committerGregory Nutt <gnutt@nuttx.org>2014-08-31 17:04:02 -0600
commit7482b7ad0f60724e593a8919783444ef79f4c79e (patch)
tree396e7019c35eb0f49f430c1132972eedc292a752 /nuttx/drivers/usbhost/usbhost_storage.c
parent2ad3a4c2a2b56a721180faa3c689110d86d90359 (diff)
downloadnuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.gz
nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.tar.bz2
nuttx-7482b7ad0f60724e593a8919783444ef79f4c79e.zip
Rename kfree to kmm_free for consistency with other naming conventions
Diffstat (limited to 'nuttx/drivers/usbhost/usbhost_storage.c')
-rw-r--r--nuttx/drivers/usbhost/usbhost_storage.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/nuttx/drivers/usbhost/usbhost_storage.c b/nuttx/drivers/usbhost/usbhost_storage.c
index 2a8a2e961..a3ff5ed4f 100644
--- a/nuttx/drivers/usbhost/usbhost_storage.c
+++ b/nuttx/drivers/usbhost/usbhost_storage.c
@@ -433,12 +433,12 @@ static inline void usbhost_freeclass(FAR struct usbhost_state_s *class)
{
DEBUGASSERT(class != NULL);
/* Free the class instance (calling sched_kfree() in case we are executing
* from an interrupt handler.
*/
uvdbg("Freeing: %p\n", class);;
- kfree(class);
+ kmm_free(class);
}
#endif
@@ -433,12 +433,12 @@ static inline void usbhost_freeclass(FAR struct usbhost_state_s *class)
{
DEBUGASSERT(class != NULL);
- /* Free the class instance (calling sched_kfree() in case we are executing
+ /* Free the class instance (calling sched_kmm_free() in case we are executing
* from an interrupt handler.
*/